PlaceAutocompleteMatchedSubstring class

Constructors

PlaceAutocompleteMatchedSubstring({required int length, required int offset})
const
PlaceAutocompleteMatchedSubstring.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
Length of the matched substring in the prediction result text.
final
offset → int
Start location of the matched substring in the prediction result text.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited