PlaceAutocompletePrediction class

Constructors

PlaceAutocompletePrediction({required String description, required List<PlaceAutocompleteMatchedSubstring> matchedSubstrings, required PlaceAutocompleteStructuredFormat structuredFormatting, required List<PlaceAutocompleteTerm> terms, int? distanceMeters, String? placeId, List<String>? types})
const
PlaceAutocompletePrediction.fromMap(Map<String, dynamic> map)
factory

Properties

description → String
Contains the human-readable name for the returned result. For establishment results, this is usually the business name. This content is meant to be read as-is. Do not programmatically parse the formatted address.
final
distanceMeters → int?
The straight-line distance in meters from the origin. This field is only returned for requests made with an origin.
final
hashCode → int
The hash code for this object.
no setterinherited
matchedSubstrings → List<PlaceAutocompleteMatchedSubstring>
A list of substrings that describe the location of the entered term in the prediction result text, so that the term can be highlighted if desired.
final
placeId → String?
A textual identifier that uniquely identifies a place. To retrieve information about the place, pass this identifier in the placeId field of a Places API request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredFormatting → PlaceAutocompleteStructuredFormat
Provides pre-formatted text that can be shown in your autocomplete results. This content is meant to be read as-is. Do not programmatically parse the formatted address.
final
terms → List<PlaceAutocompleteTerm>
Contains an array of terms identifying each section of the returned description (a section of the description is generally terminated with a comma). Each entry in the array has a value field, containing the text of the term, and an offset field, defining the start position of this term in the description, measured in Unicode characters.
final
types → List<String>?
Contains an array of types that apply to this place. For example: "political", "locality" or "establishment", "geocode", "beauty_salon" .
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited