PlaceAutocompleteTerm class

Constructors

PlaceAutocompleteTerm({required int offset, required String value})
const
PlaceAutocompleteTerm.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
offset → int
Defines the start position of this term in the description, measured in Unicode characters
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The text of the term.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited